paymentorderrecipient

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 26, 2025 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the paymentorderrecipient type in the database.
	Label = "payment_order_recipient"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldInstitution holds the string denoting the institution field in the database.
	FieldInstitution = "institution"
	// FieldAccountIdentifier holds the string denoting the account_identifier field in the database.
	FieldAccountIdentifier = "account_identifier"
	// FieldAccountName holds the string denoting the account_name field in the database.
	FieldAccountName = "account_name"
	// FieldMemo holds the string denoting the memo field in the database.
	FieldMemo = "memo"
	// FieldProviderID holds the string denoting the provider_id field in the database.
	FieldProviderID = "provider_id"
	// FieldMetadata holds the string denoting the metadata field in the database.
	FieldMetadata = "metadata"
	// EdgePaymentOrder holds the string denoting the payment_order edge name in mutations.
	EdgePaymentOrder = "payment_order"
	// Table holds the table name of the paymentorderrecipient in the database.
	Table = "payment_order_recipients"
	// PaymentOrderTable is the table that holds the payment_order relation/edge.
	PaymentOrderTable = "payment_order_recipients"
	// PaymentOrderInverseTable is the table name for the PaymentOrder entity.
	// It exists in this package in order to avoid circular dependency with the "paymentorder" package.
	PaymentOrderInverseTable = "payment_orders"
	// PaymentOrderColumn is the table column denoting the payment_order relation/edge.
	PaymentOrderColumn = "payment_order_recipient"
)

Variables

Columns holds all SQL columns for paymentorderrecipient fields.

var ForeignKeys = []string{
	"payment_order_recipient",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "payment_order_recipients" table and are not defined as standalone fields in the schema.

Functions

func AccountIdentifier

func AccountIdentifier(v string) predicate.PaymentOrderRecipient

AccountIdentifier applies equality check predicate on the "account_identifier" field. It's identical to AccountIdentifierEQ.

func AccountIdentifierContains

func AccountIdentifierContains(v string) predicate.PaymentOrderRecipient

AccountIdentifierContains applies the Contains predicate on the "account_identifier" field.

func AccountIdentifierContainsFold

func AccountIdentifierContainsFold(v string) predicate.PaymentOrderRecipient

AccountIdentifierContainsFold applies the ContainsFold predicate on the "account_identifier" field.

func AccountIdentifierEQ

func AccountIdentifierEQ(v string) predicate.PaymentOrderRecipient

AccountIdentifierEQ applies the EQ predicate on the "account_identifier" field.

func AccountIdentifierEqualFold

func AccountIdentifierEqualFold(v string) predicate.PaymentOrderRecipient

AccountIdentifierEqualFold applies the EqualFold predicate on the "account_identifier" field.

func AccountIdentifierGT

func AccountIdentifierGT(v string) predicate.PaymentOrderRecipient

AccountIdentifierGT applies the GT predicate on the "account_identifier" field.

func AccountIdentifierGTE

func AccountIdentifierGTE(v string) predicate.PaymentOrderRecipient

AccountIdentifierGTE applies the GTE predicate on the "account_identifier" field.

func AccountIdentifierHasPrefix

func AccountIdentifierHasPrefix(v string) predicate.PaymentOrderRecipient

AccountIdentifierHasPrefix applies the HasPrefix predicate on the "account_identifier" field.

func AccountIdentifierHasSuffix

func AccountIdentifierHasSuffix(v string) predicate.PaymentOrderRecipient

AccountIdentifierHasSuffix applies the HasSuffix predicate on the "account_identifier" field.

func AccountIdentifierIn

func AccountIdentifierIn(vs ...string) predicate.PaymentOrderRecipient

AccountIdentifierIn applies the In predicate on the "account_identifier" field.

func AccountIdentifierLT

func AccountIdentifierLT(v string) predicate.PaymentOrderRecipient

AccountIdentifierLT applies the LT predicate on the "account_identifier" field.

func AccountIdentifierLTE

func AccountIdentifierLTE(v string) predicate.PaymentOrderRecipient

AccountIdentifierLTE applies the LTE predicate on the "account_identifier" field.

func AccountIdentifierNEQ

func AccountIdentifierNEQ(v string) predicate.PaymentOrderRecipient

AccountIdentifierNEQ applies the NEQ predicate on the "account_identifier" field.

func AccountIdentifierNotIn

func AccountIdentifierNotIn(vs ...string) predicate.PaymentOrderRecipient

AccountIdentifierNotIn applies the NotIn predicate on the "account_identifier" field.

func AccountName

func AccountName(v string) predicate.PaymentOrderRecipient

AccountName applies equality check predicate on the "account_name" field. It's identical to AccountNameEQ.

func AccountNameContains

func AccountNameContains(v string) predicate.PaymentOrderRecipient

AccountNameContains applies the Contains predicate on the "account_name" field.

func AccountNameContainsFold

func AccountNameContainsFold(v string) predicate.PaymentOrderRecipient

AccountNameContainsFold applies the ContainsFold predicate on the "account_name" field.

func AccountNameEQ

func AccountNameEQ(v string) predicate.PaymentOrderRecipient

AccountNameEQ applies the EQ predicate on the "account_name" field.

func AccountNameEqualFold

func AccountNameEqualFold(v string) predicate.PaymentOrderRecipient

AccountNameEqualFold applies the EqualFold predicate on the "account_name" field.

func AccountNameGT

func AccountNameGT(v string) predicate.PaymentOrderRecipient

AccountNameGT applies the GT predicate on the "account_name" field.

func AccountNameGTE

func AccountNameGTE(v string) predicate.PaymentOrderRecipient

AccountNameGTE applies the GTE predicate on the "account_name" field.

func AccountNameHasPrefix

func AccountNameHasPrefix(v string) predicate.PaymentOrderRecipient

AccountNameHasPrefix applies the HasPrefix predicate on the "account_name" field.

func AccountNameHasSuffix

func AccountNameHasSuffix(v string) predicate.PaymentOrderRecipient

AccountNameHasSuffix applies the HasSuffix predicate on the "account_name" field.

func AccountNameIn

func AccountNameIn(vs ...string) predicate.PaymentOrderRecipient

AccountNameIn applies the In predicate on the "account_name" field.

func AccountNameLT

func AccountNameLT(v string) predicate.PaymentOrderRecipient

AccountNameLT applies the LT predicate on the "account_name" field.

func AccountNameLTE

func AccountNameLTE(v string) predicate.PaymentOrderRecipient

AccountNameLTE applies the LTE predicate on the "account_name" field.

func AccountNameNEQ

func AccountNameNEQ(v string) predicate.PaymentOrderRecipient

AccountNameNEQ applies the NEQ predicate on the "account_name" field.

func AccountNameNotIn

func AccountNameNotIn(vs ...string) predicate.PaymentOrderRecipient

AccountNameNotIn applies the NotIn predicate on the "account_name" field.

func And

And groups predicates with the AND operator between them.

func HasPaymentOrder

func HasPaymentOrder() predicate.PaymentOrderRecipient

HasPaymentOrder applies the HasEdge predicate on the "payment_order" edge.

func HasPaymentOrderWith

func HasPaymentOrderWith(preds ...predicate.PaymentOrder) predicate.PaymentOrderRecipient

HasPaymentOrderWith applies the HasEdge predicate on the "payment_order" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.PaymentOrderRecipient

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.PaymentOrderRecipient

IDNotIn applies the NotIn predicate on the ID field.

func Institution

func Institution(v string) predicate.PaymentOrderRecipient

Institution applies equality check predicate on the "institution" field. It's identical to InstitutionEQ.

func InstitutionContains

func InstitutionContains(v string) predicate.PaymentOrderRecipient

InstitutionContains applies the Contains predicate on the "institution" field.

func InstitutionContainsFold

func InstitutionContainsFold(v string) predicate.PaymentOrderRecipient

InstitutionContainsFold applies the ContainsFold predicate on the "institution" field.

func InstitutionEQ

func InstitutionEQ(v string) predicate.PaymentOrderRecipient

InstitutionEQ applies the EQ predicate on the "institution" field.

func InstitutionEqualFold

func InstitutionEqualFold(v string) predicate.PaymentOrderRecipient

InstitutionEqualFold applies the EqualFold predicate on the "institution" field.

func InstitutionGT

func InstitutionGT(v string) predicate.PaymentOrderRecipient

InstitutionGT applies the GT predicate on the "institution" field.

func InstitutionGTE

func InstitutionGTE(v string) predicate.PaymentOrderRecipient

InstitutionGTE applies the GTE predicate on the "institution" field.

func InstitutionHasPrefix

func InstitutionHasPrefix(v string) predicate.PaymentOrderRecipient

InstitutionHasPrefix applies the HasPrefix predicate on the "institution" field.

func InstitutionHasSuffix

func InstitutionHasSuffix(v string) predicate.PaymentOrderRecipient

InstitutionHasSuffix applies the HasSuffix predicate on the "institution" field.

func InstitutionIn

func InstitutionIn(vs ...string) predicate.PaymentOrderRecipient

InstitutionIn applies the In predicate on the "institution" field.

func InstitutionLT

func InstitutionLT(v string) predicate.PaymentOrderRecipient

InstitutionLT applies the LT predicate on the "institution" field.

func InstitutionLTE

func InstitutionLTE(v string) predicate.PaymentOrderRecipient

InstitutionLTE applies the LTE predicate on the "institution" field.

func InstitutionNEQ

func InstitutionNEQ(v string) predicate.PaymentOrderRecipient

InstitutionNEQ applies the NEQ predicate on the "institution" field.

func InstitutionNotIn

func InstitutionNotIn(vs ...string) predicate.PaymentOrderRecipient

InstitutionNotIn applies the NotIn predicate on the "institution" field.

func Memo

Memo applies equality check predicate on the "memo" field. It's identical to MemoEQ.

func MemoContains

func MemoContains(v string) predicate.PaymentOrderRecipient

MemoContains applies the Contains predicate on the "memo" field.

func MemoContainsFold

func MemoContainsFold(v string) predicate.PaymentOrderRecipient

MemoContainsFold applies the ContainsFold predicate on the "memo" field.

func MemoEQ

MemoEQ applies the EQ predicate on the "memo" field.

func MemoEqualFold

func MemoEqualFold(v string) predicate.PaymentOrderRecipient

MemoEqualFold applies the EqualFold predicate on the "memo" field.

func MemoGT

MemoGT applies the GT predicate on the "memo" field.

func MemoGTE

MemoGTE applies the GTE predicate on the "memo" field.

func MemoHasPrefix

func MemoHasPrefix(v string) predicate.PaymentOrderRecipient

MemoHasPrefix applies the HasPrefix predicate on the "memo" field.

func MemoHasSuffix

func MemoHasSuffix(v string) predicate.PaymentOrderRecipient

MemoHasSuffix applies the HasSuffix predicate on the "memo" field.

func MemoIn

MemoIn applies the In predicate on the "memo" field.

func MemoIsNil

func MemoIsNil() predicate.PaymentOrderRecipient

MemoIsNil applies the IsNil predicate on the "memo" field.

func MemoLT

MemoLT applies the LT predicate on the "memo" field.

func MemoLTE

MemoLTE applies the LTE predicate on the "memo" field.

func MemoNEQ

MemoNEQ applies the NEQ predicate on the "memo" field.

func MemoNotIn

func MemoNotIn(vs ...string) predicate.PaymentOrderRecipient

MemoNotIn applies the NotIn predicate on the "memo" field.

func MemoNotNil

func MemoNotNil() predicate.PaymentOrderRecipient

MemoNotNil applies the NotNil predicate on the "memo" field.

func MetadataIsNil

func MetadataIsNil() predicate.PaymentOrderRecipient

MetadataIsNil applies the IsNil predicate on the "metadata" field.

func MetadataNotNil

func MetadataNotNil() predicate.PaymentOrderRecipient

MetadataNotNil applies the NotNil predicate on the "metadata" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func ProviderID

ProviderID applies equality check predicate on the "provider_id" field. It's identical to ProviderIDEQ.

func ProviderIDContains

func ProviderIDContains(v string) predicate.PaymentOrderRecipient

ProviderIDContains applies the Contains predicate on the "provider_id" field.

func ProviderIDContainsFold

func ProviderIDContainsFold(v string) predicate.PaymentOrderRecipient

ProviderIDContainsFold applies the ContainsFold predicate on the "provider_id" field.

func ProviderIDEQ

func ProviderIDEQ(v string) predicate.PaymentOrderRecipient

ProviderIDEQ applies the EQ predicate on the "provider_id" field.

func ProviderIDEqualFold

func ProviderIDEqualFold(v string) predicate.PaymentOrderRecipient

ProviderIDEqualFold applies the EqualFold predicate on the "provider_id" field.

func ProviderIDGT

func ProviderIDGT(v string) predicate.PaymentOrderRecipient

ProviderIDGT applies the GT predicate on the "provider_id" field.

func ProviderIDGTE

func ProviderIDGTE(v string) predicate.PaymentOrderRecipient

ProviderIDGTE applies the GTE predicate on the "provider_id" field.

func ProviderIDHasPrefix

func ProviderIDHasPrefix(v string) predicate.PaymentOrderRecipient

ProviderIDHasPrefix applies the HasPrefix predicate on the "provider_id" field.

func ProviderIDHasSuffix

func ProviderIDHasSuffix(v string) predicate.PaymentOrderRecipient

ProviderIDHasSuffix applies the HasSuffix predicate on the "provider_id" field.

func ProviderIDIn

func ProviderIDIn(vs ...string) predicate.PaymentOrderRecipient

ProviderIDIn applies the In predicate on the "provider_id" field.

func ProviderIDIsNil

func ProviderIDIsNil() predicate.PaymentOrderRecipient

ProviderIDIsNil applies the IsNil predicate on the "provider_id" field.

func ProviderIDLT

func ProviderIDLT(v string) predicate.PaymentOrderRecipient

ProviderIDLT applies the LT predicate on the "provider_id" field.

func ProviderIDLTE

func ProviderIDLTE(v string) predicate.PaymentOrderRecipient

ProviderIDLTE applies the LTE predicate on the "provider_id" field.

func ProviderIDNEQ

func ProviderIDNEQ(v string) predicate.PaymentOrderRecipient

ProviderIDNEQ applies the NEQ predicate on the "provider_id" field.

func ProviderIDNotIn

func ProviderIDNotIn(vs ...string) predicate.PaymentOrderRecipient

ProviderIDNotIn applies the NotIn predicate on the "provider_id" field.

func ProviderIDNotNil

func ProviderIDNotNil() predicate.PaymentOrderRecipient

ProviderIDNotNil applies the NotNil predicate on the "provider_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the PaymentOrderRecipient queries.

func ByAccountIdentifier

func ByAccountIdentifier(opts ...sql.OrderTermOption) OrderOption

ByAccountIdentifier orders the results by the account_identifier field.

func ByAccountName

func ByAccountName(opts ...sql.OrderTermOption) OrderOption

ByAccountName orders the results by the account_name field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByInstitution

func ByInstitution(opts ...sql.OrderTermOption) OrderOption

ByInstitution orders the results by the institution field.

func ByMemo

func ByMemo(opts ...sql.OrderTermOption) OrderOption

ByMemo orders the results by the memo field.

func ByPaymentOrderField

func ByPaymentOrderField(field string, opts ...sql.OrderTermOption) OrderOption

ByPaymentOrderField orders the results by payment_order field.

func ByProviderID

func ByProviderID(opts ...sql.OrderTermOption) OrderOption

ByProviderID orders the results by the provider_id field.

Jump to