providerprofile

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 26, 2025 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the providerprofile type in the database.
	Label = "provider_profile"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldTradingName holds the string denoting the trading_name field in the database.
	FieldTradingName = "trading_name"
	// FieldHostIdentifier holds the string denoting the host_identifier field in the database.
	FieldHostIdentifier = "host_identifier"
	// FieldProvisionMode holds the string denoting the provision_mode field in the database.
	FieldProvisionMode = "provision_mode"
	// FieldIsActive holds the string denoting the is_active field in the database.
	FieldIsActive = "is_active"
	// FieldIsKybVerified holds the string denoting the is_kyb_verified field in the database.
	FieldIsKybVerified = "is_kyb_verified"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldVisibilityMode holds the string denoting the visibility_mode field in the database.
	FieldVisibilityMode = "visibility_mode"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgeAPIKey holds the string denoting the api_key edge name in mutations.
	EdgeAPIKey = "api_key"
	// EdgeProviderCurrencies holds the string denoting the provider_currencies edge name in mutations.
	EdgeProviderCurrencies = "provider_currencies"
	// EdgeProvisionBuckets holds the string denoting the provision_buckets edge name in mutations.
	EdgeProvisionBuckets = "provision_buckets"
	// EdgeOrderTokens holds the string denoting the order_tokens edge name in mutations.
	EdgeOrderTokens = "order_tokens"
	// EdgeProviderRating holds the string denoting the provider_rating edge name in mutations.
	EdgeProviderRating = "provider_rating"
	// EdgeAssignedOrders holds the string denoting the assigned_orders edge name in mutations.
	EdgeAssignedOrders = "assigned_orders"
	// Table holds the table name of the providerprofile in the database.
	Table = "provider_profiles"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "provider_profiles"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_provider_profile"
	// APIKeyTable is the table that holds the api_key relation/edge.
	APIKeyTable = "api_keys"
	// APIKeyInverseTable is the table name for the APIKey entity.
	// It exists in this package in order to avoid circular dependency with the "apikey" package.
	APIKeyInverseTable = "api_keys"
	// APIKeyColumn is the table column denoting the api_key relation/edge.
	APIKeyColumn = "provider_profile_api_key"
	// ProviderCurrenciesTable is the table that holds the provider_currencies relation/edge.
	ProviderCurrenciesTable = "provider_currencies"
	// ProviderCurrenciesInverseTable is the table name for the ProviderCurrencies entity.
	// It exists in this package in order to avoid circular dependency with the "providercurrencies" package.
	ProviderCurrenciesInverseTable = "provider_currencies"
	// ProviderCurrenciesColumn is the table column denoting the provider_currencies relation/edge.
	ProviderCurrenciesColumn = "provider_profile_provider_currencies"
	// ProvisionBucketsTable is the table that holds the provision_buckets relation/edge. The primary key declared below.
	ProvisionBucketsTable = "provision_bucket_provider_profiles"
	// ProvisionBucketsInverseTable is the table name for the ProvisionBucket entity.
	// It exists in this package in order to avoid circular dependency with the "provisionbucket" package.
	ProvisionBucketsInverseTable = "provision_buckets"
	// OrderTokensTable is the table that holds the order_tokens relation/edge.
	OrderTokensTable = "provider_order_tokens"
	// OrderTokensInverseTable is the table name for the ProviderOrderToken entity.
	// It exists in this package in order to avoid circular dependency with the "providerordertoken" package.
	OrderTokensInverseTable = "provider_order_tokens"
	// OrderTokensColumn is the table column denoting the order_tokens relation/edge.
	OrderTokensColumn = "provider_profile_order_tokens"
	// ProviderRatingTable is the table that holds the provider_rating relation/edge.
	ProviderRatingTable = "provider_ratings"
	// ProviderRatingInverseTable is the table name for the ProviderRating entity.
	// It exists in this package in order to avoid circular dependency with the "providerrating" package.
	ProviderRatingInverseTable = "provider_ratings"
	// ProviderRatingColumn is the table column denoting the provider_rating relation/edge.
	ProviderRatingColumn = "provider_profile_provider_rating"
	// AssignedOrdersTable is the table that holds the assigned_orders relation/edge.
	AssignedOrdersTable = "lock_payment_orders"
	// AssignedOrdersInverseTable is the table name for the LockPaymentOrder entity.
	// It exists in this package in order to avoid circular dependency with the "lockpaymentorder" package.
	AssignedOrdersInverseTable = "lock_payment_orders"
	// AssignedOrdersColumn is the table column denoting the assigned_orders relation/edge.
	AssignedOrdersColumn = "provider_profile_assigned_orders"
)
const DefaultProvisionMode = ProvisionModeAuto

ProvisionModeAuto is the default value of the ProvisionMode enum.

const DefaultVisibilityMode = VisibilityModePublic

VisibilityModePublic is the default value of the VisibilityMode enum.

Variables

var (
	// TradingNameValidator is a validator for the "trading_name" field. It is called by the builders before save.
	TradingNameValidator func(string) error
	// DefaultIsActive holds the default value on creation for the "is_active" field.
	DefaultIsActive bool
	// DefaultIsKybVerified holds the default value on creation for the "is_kyb_verified" field.
	DefaultIsKybVerified bool
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Columns holds all SQL columns for providerprofile fields.

var ForeignKeys = []string{
	"user_provider_profile",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "provider_profiles" table and are not defined as standalone fields in the schema.

var (
	// ProvisionBucketsPrimaryKey and ProvisionBucketsColumn2 are the table columns denoting the
	// primary key for the provision_buckets relation (M2M).
	ProvisionBucketsPrimaryKey = []string{"provision_bucket_id", "provider_profile_id"}
)

Functions

func And

And groups predicates with the AND operator between them.

func HasAPIKey

func HasAPIKey() predicate.ProviderProfile

HasAPIKey applies the HasEdge predicate on the "api_key" edge.

func HasAPIKeyWith

func HasAPIKeyWith(preds ...predicate.APIKey) predicate.ProviderProfile

HasAPIKeyWith applies the HasEdge predicate on the "api_key" edge with a given conditions (other predicates).

func HasAssignedOrders

func HasAssignedOrders() predicate.ProviderProfile

HasAssignedOrders applies the HasEdge predicate on the "assigned_orders" edge.

func HasAssignedOrdersWith

func HasAssignedOrdersWith(preds ...predicate.LockPaymentOrder) predicate.ProviderProfile

HasAssignedOrdersWith applies the HasEdge predicate on the "assigned_orders" edge with a given conditions (other predicates).

func HasOrderTokens

func HasOrderTokens() predicate.ProviderProfile

HasOrderTokens applies the HasEdge predicate on the "order_tokens" edge.

func HasOrderTokensWith

func HasOrderTokensWith(preds ...predicate.ProviderOrderToken) predicate.ProviderProfile

HasOrderTokensWith applies the HasEdge predicate on the "order_tokens" edge with a given conditions (other predicates).

func HasProviderCurrencies added in v0.0.2

func HasProviderCurrencies() predicate.ProviderProfile

HasProviderCurrencies applies the HasEdge predicate on the "provider_currencies" edge.

func HasProviderCurrenciesWith added in v0.0.2

func HasProviderCurrenciesWith(preds ...predicate.ProviderCurrencies) predicate.ProviderProfile

HasProviderCurrenciesWith applies the HasEdge predicate on the "provider_currencies" edge with a given conditions (other predicates).

func HasProviderRating

func HasProviderRating() predicate.ProviderProfile

HasProviderRating applies the HasEdge predicate on the "provider_rating" edge.

func HasProviderRatingWith

func HasProviderRatingWith(preds ...predicate.ProviderRating) predicate.ProviderProfile

HasProviderRatingWith applies the HasEdge predicate on the "provider_rating" edge with a given conditions (other predicates).

func HasProvisionBuckets

func HasProvisionBuckets() predicate.ProviderProfile

HasProvisionBuckets applies the HasEdge predicate on the "provision_buckets" edge.

func HasProvisionBucketsWith

func HasProvisionBucketsWith(preds ...predicate.ProvisionBucket) predicate.ProviderProfile

HasProvisionBucketsWith applies the HasEdge predicate on the "provision_buckets" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.ProviderProfile

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.ProviderProfile

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func HostIdentifier

func HostIdentifier(v string) predicate.ProviderProfile

HostIdentifier applies equality check predicate on the "host_identifier" field. It's identical to HostIdentifierEQ.

func HostIdentifierContains

func HostIdentifierContains(v string) predicate.ProviderProfile

HostIdentifierContains applies the Contains predicate on the "host_identifier" field.

func HostIdentifierContainsFold

func HostIdentifierContainsFold(v string) predicate.ProviderProfile

HostIdentifierContainsFold applies the ContainsFold predicate on the "host_identifier" field.

func HostIdentifierEQ

func HostIdentifierEQ(v string) predicate.ProviderProfile

HostIdentifierEQ applies the EQ predicate on the "host_identifier" field.

func HostIdentifierEqualFold

func HostIdentifierEqualFold(v string) predicate.ProviderProfile

HostIdentifierEqualFold applies the EqualFold predicate on the "host_identifier" field.

func HostIdentifierGT

func HostIdentifierGT(v string) predicate.ProviderProfile

HostIdentifierGT applies the GT predicate on the "host_identifier" field.

func HostIdentifierGTE

func HostIdentifierGTE(v string) predicate.ProviderProfile

HostIdentifierGTE applies the GTE predicate on the "host_identifier" field.

func HostIdentifierHasPrefix

func HostIdentifierHasPrefix(v string) predicate.ProviderProfile

HostIdentifierHasPrefix applies the HasPrefix predicate on the "host_identifier" field.

func HostIdentifierHasSuffix

func HostIdentifierHasSuffix(v string) predicate.ProviderProfile

HostIdentifierHasSuffix applies the HasSuffix predicate on the "host_identifier" field.

func HostIdentifierIn

func HostIdentifierIn(vs ...string) predicate.ProviderProfile

HostIdentifierIn applies the In predicate on the "host_identifier" field.

func HostIdentifierIsNil

func HostIdentifierIsNil() predicate.ProviderProfile

HostIdentifierIsNil applies the IsNil predicate on the "host_identifier" field.

func HostIdentifierLT

func HostIdentifierLT(v string) predicate.ProviderProfile

HostIdentifierLT applies the LT predicate on the "host_identifier" field.

func HostIdentifierLTE

func HostIdentifierLTE(v string) predicate.ProviderProfile

HostIdentifierLTE applies the LTE predicate on the "host_identifier" field.

func HostIdentifierNEQ

func HostIdentifierNEQ(v string) predicate.ProviderProfile

HostIdentifierNEQ applies the NEQ predicate on the "host_identifier" field.

func HostIdentifierNotIn

func HostIdentifierNotIn(vs ...string) predicate.ProviderProfile

HostIdentifierNotIn applies the NotIn predicate on the "host_identifier" field.

func HostIdentifierNotNil

func HostIdentifierNotNil() predicate.ProviderProfile

HostIdentifierNotNil applies the NotNil predicate on the "host_identifier" field.

func ID

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.ProviderProfile

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.ProviderProfile

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.ProviderProfile

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.ProviderProfile

IDNotIn applies the NotIn predicate on the ID field.

func IsActive

func IsActive(v bool) predicate.ProviderProfile

IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.

func IsActiveEQ

func IsActiveEQ(v bool) predicate.ProviderProfile

IsActiveEQ applies the EQ predicate on the "is_active" field.

func IsActiveNEQ

func IsActiveNEQ(v bool) predicate.ProviderProfile

IsActiveNEQ applies the NEQ predicate on the "is_active" field.

func IsKybVerified added in v0.0.2

func IsKybVerified(v bool) predicate.ProviderProfile

IsKybVerified applies equality check predicate on the "is_kyb_verified" field. It's identical to IsKybVerifiedEQ.

func IsKybVerifiedEQ added in v0.0.2

func IsKybVerifiedEQ(v bool) predicate.ProviderProfile

IsKybVerifiedEQ applies the EQ predicate on the "is_kyb_verified" field.

func IsKybVerifiedNEQ added in v0.0.2

func IsKybVerifiedNEQ(v bool) predicate.ProviderProfile

IsKybVerifiedNEQ applies the NEQ predicate on the "is_kyb_verified" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func ProvisionModeEQ

func ProvisionModeEQ(v ProvisionMode) predicate.ProviderProfile

ProvisionModeEQ applies the EQ predicate on the "provision_mode" field.

func ProvisionModeIn

func ProvisionModeIn(vs ...ProvisionMode) predicate.ProviderProfile

ProvisionModeIn applies the In predicate on the "provision_mode" field.

func ProvisionModeNEQ

func ProvisionModeNEQ(v ProvisionMode) predicate.ProviderProfile

ProvisionModeNEQ applies the NEQ predicate on the "provision_mode" field.

func ProvisionModeNotIn

func ProvisionModeNotIn(vs ...ProvisionMode) predicate.ProviderProfile

ProvisionModeNotIn applies the NotIn predicate on the "provision_mode" field.

func ProvisionModeValidator

func ProvisionModeValidator(pm ProvisionMode) error

ProvisionModeValidator is a validator for the "provision_mode" field enum values. It is called by the builders before save.

func TradingName

func TradingName(v string) predicate.ProviderProfile

TradingName applies equality check predicate on the "trading_name" field. It's identical to TradingNameEQ.

func TradingNameContains

func TradingNameContains(v string) predicate.ProviderProfile

TradingNameContains applies the Contains predicate on the "trading_name" field.

func TradingNameContainsFold

func TradingNameContainsFold(v string) predicate.ProviderProfile

TradingNameContainsFold applies the ContainsFold predicate on the "trading_name" field.

func TradingNameEQ

func TradingNameEQ(v string) predicate.ProviderProfile

TradingNameEQ applies the EQ predicate on the "trading_name" field.

func TradingNameEqualFold

func TradingNameEqualFold(v string) predicate.ProviderProfile

TradingNameEqualFold applies the EqualFold predicate on the "trading_name" field.

func TradingNameGT

func TradingNameGT(v string) predicate.ProviderProfile

TradingNameGT applies the GT predicate on the "trading_name" field.

func TradingNameGTE

func TradingNameGTE(v string) predicate.ProviderProfile

TradingNameGTE applies the GTE predicate on the "trading_name" field.

func TradingNameHasPrefix

func TradingNameHasPrefix(v string) predicate.ProviderProfile

TradingNameHasPrefix applies the HasPrefix predicate on the "trading_name" field.

func TradingNameHasSuffix

func TradingNameHasSuffix(v string) predicate.ProviderProfile

TradingNameHasSuffix applies the HasSuffix predicate on the "trading_name" field.

func TradingNameIn

func TradingNameIn(vs ...string) predicate.ProviderProfile

TradingNameIn applies the In predicate on the "trading_name" field.

func TradingNameIsNil

func TradingNameIsNil() predicate.ProviderProfile

TradingNameIsNil applies the IsNil predicate on the "trading_name" field.

func TradingNameLT

func TradingNameLT(v string) predicate.ProviderProfile

TradingNameLT applies the LT predicate on the "trading_name" field.

func TradingNameLTE

func TradingNameLTE(v string) predicate.ProviderProfile

TradingNameLTE applies the LTE predicate on the "trading_name" field.

func TradingNameNEQ

func TradingNameNEQ(v string) predicate.ProviderProfile

TradingNameNEQ applies the NEQ predicate on the "trading_name" field.

func TradingNameNotIn

func TradingNameNotIn(vs ...string) predicate.ProviderProfile

TradingNameNotIn applies the NotIn predicate on the "trading_name" field.

func TradingNameNotNil

func TradingNameNotNil() predicate.ProviderProfile

TradingNameNotNil applies the NotNil predicate on the "trading_name" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.ProviderProfile

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.ProviderProfile

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.ProviderProfile

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.ProviderProfile

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.ProviderProfile

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.ProviderProfile

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.ProviderProfile

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.ProviderProfile

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.ProviderProfile

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func VisibilityModeEQ

func VisibilityModeEQ(v VisibilityMode) predicate.ProviderProfile

VisibilityModeEQ applies the EQ predicate on the "visibility_mode" field.

func VisibilityModeIn

func VisibilityModeIn(vs ...VisibilityMode) predicate.ProviderProfile

VisibilityModeIn applies the In predicate on the "visibility_mode" field.

func VisibilityModeNEQ

func VisibilityModeNEQ(v VisibilityMode) predicate.ProviderProfile

VisibilityModeNEQ applies the NEQ predicate on the "visibility_mode" field.

func VisibilityModeNotIn

func VisibilityModeNotIn(vs ...VisibilityMode) predicate.ProviderProfile

VisibilityModeNotIn applies the NotIn predicate on the "visibility_mode" field.

func VisibilityModeValidator

func VisibilityModeValidator(vm VisibilityMode) error

VisibilityModeValidator is a validator for the "visibility_mode" field enum values. It is called by the builders before save.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the ProviderProfile queries.

func ByAPIKeyField

func ByAPIKeyField(field string, opts ...sql.OrderTermOption) OrderOption

ByAPIKeyField orders the results by api_key field.

func ByAssignedOrders

func ByAssignedOrders(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByAssignedOrders orders the results by assigned_orders terms.

func ByAssignedOrdersCount

func ByAssignedOrdersCount(opts ...sql.OrderTermOption) OrderOption

ByAssignedOrdersCount orders the results by assigned_orders count.

func ByHostIdentifier

func ByHostIdentifier(opts ...sql.OrderTermOption) OrderOption

ByHostIdentifier orders the results by the host_identifier field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIsActive

func ByIsActive(opts ...sql.OrderTermOption) OrderOption

ByIsActive orders the results by the is_active field.

func ByIsKybVerified added in v0.0.2

func ByIsKybVerified(opts ...sql.OrderTermOption) OrderOption

ByIsKybVerified orders the results by the is_kyb_verified field.

func ByOrderTokens

func ByOrderTokens(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByOrderTokens orders the results by order_tokens terms.

func ByOrderTokensCount

func ByOrderTokensCount(opts ...sql.OrderTermOption) OrderOption

ByOrderTokensCount orders the results by order_tokens count.

func ByProviderCurrencies added in v0.0.2

func ByProviderCurrencies(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByProviderCurrencies orders the results by provider_currencies terms.

func ByProviderCurrenciesCount added in v0.0.2

func ByProviderCurrenciesCount(opts ...sql.OrderTermOption) OrderOption

ByProviderCurrenciesCount orders the results by provider_currencies count.

func ByProviderRatingField

func ByProviderRatingField(field string, opts ...sql.OrderTermOption) OrderOption

ByProviderRatingField orders the results by provider_rating field.

func ByProvisionBuckets

func ByProvisionBuckets(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByProvisionBuckets orders the results by provision_buckets terms.

func ByProvisionBucketsCount

func ByProvisionBucketsCount(opts ...sql.OrderTermOption) OrderOption

ByProvisionBucketsCount orders the results by provision_buckets count.

func ByProvisionMode

func ByProvisionMode(opts ...sql.OrderTermOption) OrderOption

ByProvisionMode orders the results by the provision_mode field.

func ByTradingName

func ByTradingName(opts ...sql.OrderTermOption) OrderOption

ByTradingName orders the results by the trading_name field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByVisibilityMode

func ByVisibilityMode(opts ...sql.OrderTermOption) OrderOption

ByVisibilityMode orders the results by the visibility_mode field.

type ProvisionMode

type ProvisionMode string

ProvisionMode defines the type for the "provision_mode" enum field.

const (
	ProvisionModeManual ProvisionMode = "manual"
	ProvisionModeAuto   ProvisionMode = "auto"
)

ProvisionMode values.

func (ProvisionMode) String

func (pm ProvisionMode) String() string

type VisibilityMode

type VisibilityMode string

VisibilityMode defines the type for the "visibility_mode" enum field.

const (
	VisibilityModePrivate VisibilityMode = "private"
	VisibilityModePublic  VisibilityMode = "public"
)

VisibilityMode values.

func (VisibilityMode) String

func (vm VisibilityMode) String() string

Jump to