webhookretryattempt

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 26, 2025 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the webhookretryattempt type in the database.
	Label = "webhook_retry_attempt"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldAttemptNumber holds the string denoting the attempt_number field in the database.
	FieldAttemptNumber = "attempt_number"
	// FieldNextRetryTime holds the string denoting the next_retry_time field in the database.
	FieldNextRetryTime = "next_retry_time"
	// FieldPayload holds the string denoting the payload field in the database.
	FieldPayload = "payload"
	// FieldSignature holds the string denoting the signature field in the database.
	FieldSignature = "signature"
	// FieldWebhookURL holds the string denoting the webhook_url field in the database.
	FieldWebhookURL = "webhook_url"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// Table holds the table name of the webhookretryattempt in the database.
	Table = "webhook_retry_attempts"
)
const DefaultStatus = StatusFailed

StatusFailed is the default value of the Status enum.

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultNextRetryTime holds the default value on creation for the "next_retry_time" field.
	DefaultNextRetryTime func() time.Time
)

Columns holds all SQL columns for webhookretryattempt fields.

Functions

func And

And groups predicates with the AND operator between them.

func AttemptNumber

func AttemptNumber(v int) predicate.WebhookRetryAttempt

AttemptNumber applies equality check predicate on the "attempt_number" field. It's identical to AttemptNumberEQ.

func AttemptNumberEQ

func AttemptNumberEQ(v int) predicate.WebhookRetryAttempt

AttemptNumberEQ applies the EQ predicate on the "attempt_number" field.

func AttemptNumberGT

func AttemptNumberGT(v int) predicate.WebhookRetryAttempt

AttemptNumberGT applies the GT predicate on the "attempt_number" field.

func AttemptNumberGTE

func AttemptNumberGTE(v int) predicate.WebhookRetryAttempt

AttemptNumberGTE applies the GTE predicate on the "attempt_number" field.

func AttemptNumberIn

func AttemptNumberIn(vs ...int) predicate.WebhookRetryAttempt

AttemptNumberIn applies the In predicate on the "attempt_number" field.

func AttemptNumberLT

func AttemptNumberLT(v int) predicate.WebhookRetryAttempt

AttemptNumberLT applies the LT predicate on the "attempt_number" field.

func AttemptNumberLTE

func AttemptNumberLTE(v int) predicate.WebhookRetryAttempt

AttemptNumberLTE applies the LTE predicate on the "attempt_number" field.

func AttemptNumberNEQ

func AttemptNumberNEQ(v int) predicate.WebhookRetryAttempt

AttemptNumberNEQ applies the NEQ predicate on the "attempt_number" field.

func AttemptNumberNotIn

func AttemptNumberNotIn(vs ...int) predicate.WebhookRetryAttempt

AttemptNumberNotIn applies the NotIn predicate on the "attempt_number" field.

func CreatedAt

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.WebhookRetryAttempt

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.WebhookRetryAttempt

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.WebhookRetryAttempt

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.WebhookRetryAttempt

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.WebhookRetryAttempt

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.WebhookRetryAttempt

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.WebhookRetryAttempt

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.WebhookRetryAttempt

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.WebhookRetryAttempt

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.WebhookRetryAttempt

IDNotIn applies the NotIn predicate on the ID field.

func NextRetryTime

func NextRetryTime(v time.Time) predicate.WebhookRetryAttempt

NextRetryTime applies equality check predicate on the "next_retry_time" field. It's identical to NextRetryTimeEQ.

func NextRetryTimeEQ

func NextRetryTimeEQ(v time.Time) predicate.WebhookRetryAttempt

NextRetryTimeEQ applies the EQ predicate on the "next_retry_time" field.

func NextRetryTimeGT

func NextRetryTimeGT(v time.Time) predicate.WebhookRetryAttempt

NextRetryTimeGT applies the GT predicate on the "next_retry_time" field.

func NextRetryTimeGTE

func NextRetryTimeGTE(v time.Time) predicate.WebhookRetryAttempt

NextRetryTimeGTE applies the GTE predicate on the "next_retry_time" field.

func NextRetryTimeIn

func NextRetryTimeIn(vs ...time.Time) predicate.WebhookRetryAttempt

NextRetryTimeIn applies the In predicate on the "next_retry_time" field.

func NextRetryTimeLT

func NextRetryTimeLT(v time.Time) predicate.WebhookRetryAttempt

NextRetryTimeLT applies the LT predicate on the "next_retry_time" field.

func NextRetryTimeLTE

func NextRetryTimeLTE(v time.Time) predicate.WebhookRetryAttempt

NextRetryTimeLTE applies the LTE predicate on the "next_retry_time" field.

func NextRetryTimeNEQ

func NextRetryTimeNEQ(v time.Time) predicate.WebhookRetryAttempt

NextRetryTimeNEQ applies the NEQ predicate on the "next_retry_time" field.

func NextRetryTimeNotIn

func NextRetryTimeNotIn(vs ...time.Time) predicate.WebhookRetryAttempt

NextRetryTimeNotIn applies the NotIn predicate on the "next_retry_time" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func Signature

Signature applies equality check predicate on the "signature" field. It's identical to SignatureEQ.

func SignatureContains

func SignatureContains(v string) predicate.WebhookRetryAttempt

SignatureContains applies the Contains predicate on the "signature" field.

func SignatureContainsFold

func SignatureContainsFold(v string) predicate.WebhookRetryAttempt

SignatureContainsFold applies the ContainsFold predicate on the "signature" field.

func SignatureEQ

func SignatureEQ(v string) predicate.WebhookRetryAttempt

SignatureEQ applies the EQ predicate on the "signature" field.

func SignatureEqualFold

func SignatureEqualFold(v string) predicate.WebhookRetryAttempt

SignatureEqualFold applies the EqualFold predicate on the "signature" field.

func SignatureGT

func SignatureGT(v string) predicate.WebhookRetryAttempt

SignatureGT applies the GT predicate on the "signature" field.

func SignatureGTE

func SignatureGTE(v string) predicate.WebhookRetryAttempt

SignatureGTE applies the GTE predicate on the "signature" field.

func SignatureHasPrefix

func SignatureHasPrefix(v string) predicate.WebhookRetryAttempt

SignatureHasPrefix applies the HasPrefix predicate on the "signature" field.

func SignatureHasSuffix

func SignatureHasSuffix(v string) predicate.WebhookRetryAttempt

SignatureHasSuffix applies the HasSuffix predicate on the "signature" field.

func SignatureIn

func SignatureIn(vs ...string) predicate.WebhookRetryAttempt

SignatureIn applies the In predicate on the "signature" field.

func SignatureIsNil

func SignatureIsNil() predicate.WebhookRetryAttempt

SignatureIsNil applies the IsNil predicate on the "signature" field.

func SignatureLT

func SignatureLT(v string) predicate.WebhookRetryAttempt

SignatureLT applies the LT predicate on the "signature" field.

func SignatureLTE

func SignatureLTE(v string) predicate.WebhookRetryAttempt

SignatureLTE applies the LTE predicate on the "signature" field.

func SignatureNEQ

func SignatureNEQ(v string) predicate.WebhookRetryAttempt

SignatureNEQ applies the NEQ predicate on the "signature" field.

func SignatureNotIn

func SignatureNotIn(vs ...string) predicate.WebhookRetryAttempt

SignatureNotIn applies the NotIn predicate on the "signature" field.

func SignatureNotNil

func SignatureNotNil() predicate.WebhookRetryAttempt

SignatureNotNil applies the NotNil predicate on the "signature" field.

func StatusEQ

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

func StatusIn(vs ...Status) predicate.WebhookRetryAttempt

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...Status) predicate.WebhookRetryAttempt

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s Status) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func UpdatedAt

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.WebhookRetryAttempt

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.WebhookRetryAttempt

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.WebhookRetryAttempt

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.WebhookRetryAttempt

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.WebhookRetryAttempt

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.WebhookRetryAttempt

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.WebhookRetryAttempt

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.WebhookRetryAttempt

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func WebhookURL

func WebhookURL(v string) predicate.WebhookRetryAttempt

WebhookURL applies equality check predicate on the "webhook_url" field. It's identical to WebhookURLEQ.

func WebhookURLContains

func WebhookURLContains(v string) predicate.WebhookRetryAttempt

WebhookURLContains applies the Contains predicate on the "webhook_url" field.

func WebhookURLContainsFold

func WebhookURLContainsFold(v string) predicate.WebhookRetryAttempt

WebhookURLContainsFold applies the ContainsFold predicate on the "webhook_url" field.

func WebhookURLEQ

func WebhookURLEQ(v string) predicate.WebhookRetryAttempt

WebhookURLEQ applies the EQ predicate on the "webhook_url" field.

func WebhookURLEqualFold

func WebhookURLEqualFold(v string) predicate.WebhookRetryAttempt

WebhookURLEqualFold applies the EqualFold predicate on the "webhook_url" field.

func WebhookURLGT

func WebhookURLGT(v string) predicate.WebhookRetryAttempt

WebhookURLGT applies the GT predicate on the "webhook_url" field.

func WebhookURLGTE

func WebhookURLGTE(v string) predicate.WebhookRetryAttempt

WebhookURLGTE applies the GTE predicate on the "webhook_url" field.

func WebhookURLHasPrefix

func WebhookURLHasPrefix(v string) predicate.WebhookRetryAttempt

WebhookURLHasPrefix applies the HasPrefix predicate on the "webhook_url" field.

func WebhookURLHasSuffix

func WebhookURLHasSuffix(v string) predicate.WebhookRetryAttempt

WebhookURLHasSuffix applies the HasSuffix predicate on the "webhook_url" field.

func WebhookURLIn

func WebhookURLIn(vs ...string) predicate.WebhookRetryAttempt

WebhookURLIn applies the In predicate on the "webhook_url" field.

func WebhookURLLT

func WebhookURLLT(v string) predicate.WebhookRetryAttempt

WebhookURLLT applies the LT predicate on the "webhook_url" field.

func WebhookURLLTE

func WebhookURLLTE(v string) predicate.WebhookRetryAttempt

WebhookURLLTE applies the LTE predicate on the "webhook_url" field.

func WebhookURLNEQ

func WebhookURLNEQ(v string) predicate.WebhookRetryAttempt

WebhookURLNEQ applies the NEQ predicate on the "webhook_url" field.

func WebhookURLNotIn

func WebhookURLNotIn(vs ...string) predicate.WebhookRetryAttempt

WebhookURLNotIn applies the NotIn predicate on the "webhook_url" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the WebhookRetryAttempt queries.

func ByAttemptNumber

func ByAttemptNumber(opts ...sql.OrderTermOption) OrderOption

ByAttemptNumber orders the results by the attempt_number field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByNextRetryTime

func ByNextRetryTime(opts ...sql.OrderTermOption) OrderOption

ByNextRetryTime orders the results by the next_retry_time field.

func BySignature

func BySignature(opts ...sql.OrderTermOption) OrderOption

BySignature orders the results by the signature field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByWebhookURL

func ByWebhookURL(opts ...sql.OrderTermOption) OrderOption

ByWebhookURL orders the results by the webhook_url field.

type Status

type Status string

Status defines the type for the "status" enum field.

const (
	StatusSuccess Status = "success"
	StatusFailed  Status = "failed"
	StatusExpired Status = "expired"
)

Status values.

func (Status) String

func (s Status) String() string

Jump to