Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.APIKey) predicate.APIKey
- func HasPaymentOrders() predicate.APIKey
- func HasPaymentOrdersWith(preds ...predicate.PaymentOrder) predicate.APIKey
- func HasProviderProfile() predicate.APIKey
- func HasProviderProfileWith(preds ...predicate.ProviderProfile) predicate.APIKey
- func HasSenderProfile() predicate.APIKey
- func HasSenderProfileWith(preds ...predicate.SenderProfile) predicate.APIKey
- func ID(id uuid.UUID) predicate.APIKey
- func IDEQ(id uuid.UUID) predicate.APIKey
- func IDGT(id uuid.UUID) predicate.APIKey
- func IDGTE(id uuid.UUID) predicate.APIKey
- func IDIn(ids ...uuid.UUID) predicate.APIKey
- func IDLT(id uuid.UUID) predicate.APIKey
- func IDLTE(id uuid.UUID) predicate.APIKey
- func IDNEQ(id uuid.UUID) predicate.APIKey
- func IDNotIn(ids ...uuid.UUID) predicate.APIKey
- func Not(p predicate.APIKey) predicate.APIKey
- func Or(predicates ...predicate.APIKey) predicate.APIKey
- func Secret(v string) predicate.APIKey
- func SecretContains(v string) predicate.APIKey
- func SecretContainsFold(v string) predicate.APIKey
- func SecretEQ(v string) predicate.APIKey
- func SecretEqualFold(v string) predicate.APIKey
- func SecretGT(v string) predicate.APIKey
- func SecretGTE(v string) predicate.APIKey
- func SecretHasPrefix(v string) predicate.APIKey
- func SecretHasSuffix(v string) predicate.APIKey
- func SecretIn(vs ...string) predicate.APIKey
- func SecretLT(v string) predicate.APIKey
- func SecretLTE(v string) predicate.APIKey
- func SecretNEQ(v string) predicate.APIKey
- func SecretNotIn(vs ...string) predicate.APIKey
- func ValidColumn(column string) bool
- type OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByPaymentOrders(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByPaymentOrdersCount(opts ...sql.OrderTermOption) OrderOption
- func ByProviderProfileField(field string, opts ...sql.OrderTermOption) OrderOption
- func BySecret(opts ...sql.OrderTermOption) OrderOption
- func BySenderProfileField(field string, opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the apikey type in the database. Label = "api_key" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldSecret holds the string denoting the secret field in the database. FieldSecret = "secret" // EdgeSenderProfile holds the string denoting the sender_profile edge name in mutations. EdgeSenderProfile = "sender_profile" // EdgeProviderProfile holds the string denoting the provider_profile edge name in mutations. EdgeProviderProfile = "provider_profile" // EdgePaymentOrders holds the string denoting the payment_orders edge name in mutations. EdgePaymentOrders = "payment_orders" // Table holds the table name of the apikey in the database. Table = "api_keys" // SenderProfileTable is the table that holds the sender_profile relation/edge. SenderProfileTable = "api_keys" // SenderProfileInverseTable is the table name for the SenderProfile entity. // It exists in this package in order to avoid circular dependency with the "senderprofile" package. SenderProfileInverseTable = "sender_profiles" // SenderProfileColumn is the table column denoting the sender_profile relation/edge. SenderProfileColumn = "sender_profile_api_key" // ProviderProfileTable is the table that holds the provider_profile relation/edge. ProviderProfileTable = "api_keys" // ProviderProfileInverseTable is the table name for the ProviderProfile entity. // It exists in this package in order to avoid circular dependency with the "providerprofile" package. ProviderProfileInverseTable = "provider_profiles" // ProviderProfileColumn is the table column denoting the provider_profile relation/edge. ProviderProfileColumn = "provider_profile_api_key" // PaymentOrdersTable is the table that holds the payment_orders relation/edge. PaymentOrdersTable = "payment_orders" // PaymentOrdersInverseTable is the table name for the PaymentOrder entity. // It exists in this package in order to avoid circular dependency with the "paymentorder" package. PaymentOrdersInverseTable = "payment_orders" // PaymentOrdersColumn is the table column denoting the payment_orders relation/edge. PaymentOrdersColumn = "api_key_payment_orders" )
Variables ¶
var ( // SecretValidator is a validator for the "secret" field. It is called by the builders before save. SecretValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldSecret, }
Columns holds all SQL columns for apikey fields.
var ForeignKeys = []string{
"provider_profile_api_key",
"sender_profile_api_key",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "api_keys" table and are not defined as standalone fields in the schema.
Functions ¶
func HasPaymentOrders ¶
HasPaymentOrders applies the HasEdge predicate on the "payment_orders" edge.
func HasPaymentOrdersWith ¶
func HasPaymentOrdersWith(preds ...predicate.PaymentOrder) predicate.APIKey
HasPaymentOrdersWith applies the HasEdge predicate on the "payment_orders" edge with a given conditions (other predicates).
func HasProviderProfile ¶
HasProviderProfile applies the HasEdge predicate on the "provider_profile" edge.
func HasProviderProfileWith ¶
func HasProviderProfileWith(preds ...predicate.ProviderProfile) predicate.APIKey
HasProviderProfileWith applies the HasEdge predicate on the "provider_profile" edge with a given conditions (other predicates).
func HasSenderProfile ¶
HasSenderProfile applies the HasEdge predicate on the "sender_profile" edge.
func HasSenderProfileWith ¶
func HasSenderProfileWith(preds ...predicate.SenderProfile) predicate.APIKey
HasSenderProfileWith applies the HasEdge predicate on the "sender_profile" edge with a given conditions (other predicates).
func Secret ¶
Secret applies equality check predicate on the "secret" field. It's identical to SecretEQ.
func SecretContains ¶
SecretContains applies the Contains predicate on the "secret" field.
func SecretContainsFold ¶
SecretContainsFold applies the ContainsFold predicate on the "secret" field.
func SecretEqualFold ¶
SecretEqualFold applies the EqualFold predicate on the "secret" field.
func SecretHasPrefix ¶
SecretHasPrefix applies the HasPrefix predicate on the "secret" field.
func SecretHasSuffix ¶
SecretHasSuffix applies the HasSuffix predicate on the "secret" field.
func SecretNotIn ¶
SecretNotIn applies the NotIn predicate on the "secret" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the APIKey queries.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByPaymentOrders ¶
func ByPaymentOrders(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByPaymentOrders orders the results by payment_orders terms.
func ByPaymentOrdersCount ¶
func ByPaymentOrdersCount(opts ...sql.OrderTermOption) OrderOption
ByPaymentOrdersCount orders the results by payment_orders count.
func ByProviderProfileField ¶
func ByProviderProfileField(field string, opts ...sql.OrderTermOption) OrderOption
ByProviderProfileField orders the results by provider_profile field.
func BySecret ¶
func BySecret(opts ...sql.OrderTermOption) OrderOption
BySecret orders the results by the secret field.
func BySenderProfileField ¶
func BySenderProfileField(field string, opts ...sql.OrderTermOption) OrderOption
BySenderProfileField orders the results by sender_profile field.